@@ -3,8 +3,6 @@
 ################################
 "dialog.cca" <- function(show, history)
 {
-	op=options()
-	options(warn=-1)
 #
 # Main dialog window with title
 #
@@ -139,12 +137,11 @@
 	#
 	# Execute the command
 	#
-#		ade4TkGUIFlag <<- 1
-		assign("ade4TkGUIFlag", 1, envir=.GlobalEnv)
+		assign("ade4TkGUIFlag", 1, envir=env_ade4tkgui)
 		myObject <- eval.parent(cmd)
-		assign(eval(dudiout), myObject, pos=1)
+		assign(eval(dudiout), myObject, envir=env_ade4tkgui)
 		dialog.dudi.display(show, history, eval(dudiout))
-		rm("ade4TkGUIFlag", envir=.GlobalEnv)
+		rm("ade4TkGUIFlag", envir=env_ade4tkgui)
 		if (history) {
 			commande = paste(eval(dudiout), " <- ", deparse(cmd, width.cutoff = 500), sep = "")
 			rewriteHistory(commande)
